@@ -1,4 +1,5 @@
 from Musicians import *
+from random import randrange
 
 """
 
@@ -20,7 +21,6 @@ from Musicians import *
 dummy_parameters = {'channel': 1}
 
 dummy = [
-	#SimpleChordInstrument({'channel': 1, 'start': 16}), 
 	SlowStridePianist({'max_velocity': 80, 'start': 0, 'step': 2 }),
 	FastStridePianist({'max_velocity': 80, 'start': 2, 'step': 2}),
 	RockDrum({'start': 0}),
@@ -39,13 +39,17 @@ swing = [
 	ChordInstrument({'channel':7, 'chance': 0.15, 'max_velocity': 70}), 
 	SlowStridePianist({'max_velocity': 80}),
 	RockDrum({'start': 0}),
-	SoloInstrument({'channel':11}),
+	SoloInstrument({'channel':11, 'midi_instr': 66, 'start': 0, 'step': 4}),
+	SoloInstrument({'channel':12, 'midi_instr': 11, 'start': 4, 'step': 4}),
+	BassInstrument({'channel':5, 'midi_instr':36, 'let_ring': True}),
+	SimpleChordInstrument({'channel': 1, 'start': 1, 'midi_instr': 49, 'step': 1}), 
 	]
 
 boogie = [
-	BoogieWoogieRhythm({'channel': 1}),
+	BoogieWoogieRhythm({'channel': 1, 'midi_instr': randrange(25, 31)}),
 	RockDrum({}),
-	SoloInstrument({'channel':11}),
+	SoloInstrument({'channel':11, 'midi_instr': randrange(25, 90)}),
+	BassInstrument({'channel':5, 'midi_instr':36, 'let_ring': True}),
 	]
 
 metal = [
@@ -56,12 +60,12 @@ metal = [
 	]
 
 jazz = [
-	SoloInstrument({'midi_instr': 11, 'channel': 11, 'start': 0, 'step': 4}),
-	SoloInstrument({'midi_instr': 57,'channel': 15, 'start': 4, 'stop': 8, 'step': 4, 'max_velocity': 80}),
+	SimpleChordInstrument({'channel': 1}),
 	BassInstrument({'channel': 2, 'start': 0, 'let_ring': True}),
 	SlowStridePianist({'channel': 3, 'start':0, 'step': 4, 'max_velocity': 70}),
-	FastStridePianist({'channel': 5, 'start':4, 'step': 4}),
 	ChordInstrument({'channel': 4, 'max_velocity': 70, 'chance': 0.5, 'start': 4, 'midi_instr': 1}),
-	SimpleChordInstrument({'channel': 1}),
+	FastStridePianist({'channel': 5, 'start':4, 'step': 4}),
 	RockDrum({}),
+	SoloInstrument({'midi_instr': 11, 'channel': 11, 'start': 0, 'step': 4}),
+	SoloInstrument({'midi_instr': 66,'channel': 15, 'start': 4, 'stop': 8, 'step': 4, 'max_velocity': 80}),
 	]
