@@ -6,6 +6,8 @@ from optparse import OptionParser
 from mingus.core import notes
 import Bands
 import Progressions
+import Musicians
+from Instrument import Instrument
 
 try:
 	from mingus.extra import fluidsynth
@@ -23,6 +25,11 @@ def get_available_progressions():
 		type(getattr(Progressions, x)) == type([]) and \
 		x[0] != "_"]
 
+def get_available_instruments():
+	return [x for x in Bands.__dict__ if type(getattr(Bands, x)) == \
+		type(Instrument) and issubclass(getattr(Bands,x), Instrument)]
+
+
 if __name__ == '__main__':
 
 	parser = OptionParser()
@@ -36,6 +43,7 @@ if __name__ == '__main__':
 		metavar="F", help="Choose front-end [blocks, lines, mixed]")
 	parser.add_option("--height", dest='height', type='int',
 		default=400, help='Height of the visualization screen')
+	parser.add_option("-i", "--instrument", help="Play using only one instrument", dest="instrument")
 	parser.add_option("-l", "--list", dest="list", 
 		help="List [bands, progressions]. Don't play.")
 	parser.add_option("-k", "--key", dest="key",
@@ -88,6 +96,12 @@ if __name__ == '__main__':
 			for x in get_available_progressions():
 				print "%d. %s" % (i, x)
 				i += 1
+		elif options.list == "instruments" or\
+			options.list[0] == 'i':
+			i = 1
+			for x in get_available_instruments():
+				print "%d. %s" % (i, x)
+				i += 1
 		else:
 			print "Unknown list", options.list
 		sys.exit(0)
@@ -108,6 +122,14 @@ if __name__ == '__main__':
 			if options.verbose:
 				print "Unknown progression:", options.progression
 
+	if options.instrument != None:
+		if options.instrument in get_available_instruments():
+			block.instruments = [getattr(Musicians, \
+					options.instrument)({})]
+		else:
+			if options.verbose:
+				print "Unknown instrument:", options.instrument
+
 	if options.key != None:
 		if notes.is_valid_note(options.key):
 			block.key = options.key
@@ -127,6 +149,7 @@ if __name__ == '__main__':
 	if not fluidsynth.init_fluidsynth():
 		print "No running fluidsynth server found at port 9800."
 		sys.exit(1)
+	fluidsynth.midi.stop_everything()
 
 	seq = Sequencer(block)
 	seq.verbose = options.verbose
