@@ -86,11 +86,12 @@ class Sequencer:
 		"""Plays all the instruments in self.instruments if """
 		"""they are currently enabled."""
 		
-		it = self.iterations
+		it = self.iterations -1 
 		for i in self.instruments:
 			if it >= i.start and (it < i.end or i.end == -1):
 				i.play(self.state)
 			elif it == i.end and i.step != 0:
+				i.stop_playing_notes()
 				diff = i.end - i.start
 				i.start = i.end + i.step
 				i.end = i.start + diff
@@ -175,7 +176,6 @@ class Sequencer:
 
 		tick_length = self.block.get_tick_length(self.tick, \
 				self.tick_length)
-
 		if exec_time > tick_length:
 			if self.verbose:
 				print "Tick Overflow!"
